@@ -393,7 +393,7 @@ class Project(Model):
         if key is not None:
             matchObj = re.match(r'^[-_A-Za-z0-9]+$', key, re.I | re.S)
             if matchObj:
-                self.rid = 'project/' + username + '/' + key
+                self.rid = 'model/' + username + '/' + key
                 try:
                     r = request('GET', 'resources/' + self.rid)
                     return Project.update(self)
@@ -429,7 +429,45 @@ class Project(Model):
             >>> Project.create(project)
             保存成功
         """
-        Project.update(project)
+        # Project.update(project)
+        t = '(?<=/)\\S+(?=/)'
+        username = os.environ.get('USER_NAME')
+        owner = re.search(t, model.rid)
+
+        if owner is None:
+            raise Exception('rid 错误，无法保存')
+        elif owner[0] != username:
+            raise Exception('rid 错误，无法保存')
+
+        modelQuery = """
+                    mutation($a:CreateModelInput!){createModel(input:$a){
+                                         rid
+                                }}
+                """
+        isPublic = model.context.get('auth', '') != 'private'
+        isComponent = model.context.get('category', '') == 'component'
+        publicRead = model.context.get('publicRead', '') != False
+        auth = (65539 if publicRead else 65537) if isPublic else 0
+        revision = ModelRevision.create(model.revision, model.revision.hash)
+
+        return graphql_request(
+            modelQuery, {
+                'a': {
+                    'rid': model.rid,
+                    'revision': revision['hash'],
+                    'context': model.context,
+                    'configs': model.configs,
+                    'jobs': model.jobs,
+                    'name': model.name,
+                    'description': model.description,
+                    'tags': model.tags,
+                    "permissions": {
+                        "moderator": 1,
+                        "member": 1,
+                        "everyone": auth,
+                    },
+                }
+            })
 
     @staticmethod
     @deprecated(version='3.0', reason="该方法将在 5.0 版本移除，请使用 Model.update 方法代替")
