@@ -3,7 +3,7 @@ import json
 import time
 import random
 from .receiver import Receiver
-from .result import PowerFlowResult, EMTResult, Result
+from .result import PowerFlowResult, EMTResult, Result, IESResult
 from .storage import Storage
 from ..utils import request
 
@@ -13,16 +13,19 @@ RECEIVER = {
 RESULT_DB = {
     'job-definition/cloudpss/emtp': EMTResult,
     'job-definition/cloudpss/sfemt': EMTResult,
-    'job-definition/cloudpss/power-flow': PowerFlowResult
+    'job-definition/cloudpss/power-flow': PowerFlowResult,
+    'job-definition/cloudpss/ies-simulation': IESResult,
+    'job-definition/cloudpss/ies-optimization': IESResult,
+    'job-definition/cloudpss/three-phase-powerFlow': PowerFlowResult,
 }
 
 
 class Runner(object):
-    def __init__(self, taskId, name, job, config, revision, projectRid,
+    def __init__(self, taskId, name, job, config, revision, modelRid,
                  **kwargs):
 
         self.taskId = taskId
-        self.db = Storage(taskId, name, job, config, revision, projectRid)
+        self.db = Storage(taskId, name, job, config, revision, modelRid)
         result = RESULT_DB.get(job['rid'], EMTResult)
         self.result = result(self.db)
         self.receiver = None
@@ -82,6 +85,7 @@ class Runner(object):
         payload = {
             'args': config['args'],
             'job': job,
+            'implement': kwargs.get('topology', None)
         }
         while not runner.__listenStatus():
             time.sleep(1)
